========
hartools
========


.. image:: https://img.shields.io/pypi/v/hartools.svg
        :target: https://pypi.python.org/pypi/hartools

.. image:: https://img.shields.io/travis/carlos9917/hartools.svg
        :target: https://travis-ci.com/carlos9917/hartools

.. image:: https://readthedocs.org/projects/hartools/badge/?version=latest
        :target: https://hartools.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




Tools for processing data and monitoring output from the Harmonie arome model

This library is still VERY CRUDE. Mainly using it to pack together some functions
I need to use very frequently.

* Free software: MIT license
* Documentation: https://hartools.readthedocs.io.


Features
--------

* TODO

** Add a function in ecfs to locate the vfld files automatically. Search for the common directories
   and locate  format in which they are stored and decide if I need to unpack or not

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
